Item

Enum Item 

pub(super) enum Item<'a, const VERSION: u8> {
    Literal(&'a str),
    Component(AstComponent),
    Optional {
        value: Vec<Self>,
        format: Spanned<bool>,
        span: Span,
    },
    First {
        value: Vec<Vec<Self>>,
        span: Span,
    },
}
Available on (crate features formatting or parsing) and crate feature alloc only.
A description of how to format and parse one part of a type.

Variants



Literal(&'a str)

A literal string.



Component(AstComponent)

Part of a type, along with its modifiers.



Optional

A sequence of optional items.

Fields

value: Vec<Self>

The items themselves.

format: Spanned<bool>

Whether the value should be formatted.

span: Span

The span of the full sequence.



First

The first matching parse of a sequence of format descriptions.

Fields

value: Vec<Vec<Self>>

The sequence of format descriptions.

span: Span

The span of the full sequence.

Implementations

Source

impl<'a, const VERSION: u8> Item<'a, VERSION>

pub(super) fn optional_from_parts( opening_bracket: Location, modifiers: &[Modifier<'_>], nested_format_descriptions: Vec<NestedFormatDescription<'a, VERSION>>, closing_bracket: Location, ) -> Result<Self, Error>